package com.msl;

import com.msl.java.*;
import com.msl.java.FeignClassAnnotationUpdater;
import com.msl.java.FeignMethodAnnotationUpdater1;
import com.msl.java.FeignMethodAnnotationUpdater2;
import com.msl.java.JavaNormalUpdater;
import com.msl.xml.XmlNormalUpdater;

import java.util.ArrayList;
import java.util.List;

/**
 * @author wanglq
 * Date 2024/8/7
 * Time 13:53
 */
public class FileUpdaterManager {
    private final static List<FileUpdater> UPDATERS = new ArrayList<>();

    static {
        register(new XmlNormalUpdater());
        register(new JavaNormalUpdater());
        register(new JavaEsUpdater());
        register(new EasyPoiUpdater());
        register(new FeignClassAnnotationUpdater());
        register(new FeignMethodAnnotationUpdater1());
        register(new FeignMethodAnnotationUpdater2());
    }

    public static void register(FileUpdater fileUpdater) {
        UPDATERS.add(fileUpdater);
    }

    public static void update(FileContext context) {
        for (FileUpdater updater : UPDATERS) {
            if (updater.canApply(context)) {
                updater.update(context);
            }
        }
    }
}
