package com.msl.java;

import com.msl.FileContext;
import com.msl.FileUpdater;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @author wanglq
 * Date 2024/9/18
 * Time 17:25
 */
public class EasyPoiUpdater implements FileUpdater {
    // 定义正则表达式
    private final Pattern pattern = Pattern.compile("@Excel\\s*\\(\\s*name\\s*=\\s*\"([^\"]*)\",\\s*orderNum\\s*=\\s*\"(\\d+)\"\\s*\\)");

    /**
     * 能否更新文件
     *
     * @param context 文件上下文
     * @return 能否更新
     */
    @Override
    public boolean canApply(FileContext context) {
        return context.getFileName().endsWith(".java");
    }

    /**
     * 更新文件上下文
     *
     * @param context 文件上下文
     */
    @Override
    public void update(FileContext context) {
        String content = context.getContent().replace("import cn.afterturn.easypoi.excel.annotation.Excel;",
                "import com.alibaba.excel.annotation.ExcelProperty;");
        context.setContent(replaceAnnotation(content));
    }

    private String replaceAnnotation(String content) {
        Matcher matcher = pattern.matcher(content);
        StringBuffer sb = new StringBuffer();
        while (matcher.find()) {
            // 获取第一个捕获组的值，即 字段名
            String nameValue = matcher.group(1);
            // 获取第二个捕获组的值，即 字段序号
            String indexValue = matcher.group(2);

            // 构造替换后的注解内容
            String replaced = String.format("@ExcelProperty(value = \"%s\", index = %s)", nameValue, indexValue);

            // 替换原始文本中匹配的部分
            matcher.appendReplacement(sb, replaced);
        }
        // 将剩余部分追加到结果中
        matcher.appendTail(sb);
        return sb.toString();
    }
}
